import { IDiffResult, IOptions } from 'diff';
export declare type NodePredicate = (node: Node) => boolean;
export declare type IndefiniteNodePredicate = (node: Node) => boolean | undefined;
export declare function isElement(node: Node): node is HTMLElement;
export declare function isText(node: Node): node is Text;
export declare function isDocumentFragment(node: Node): node is DocumentFragment;
export declare function isComment(node: Node): node is Comment;
export declare type Comparator<T> = (item1: T, item2: T) => boolean;
export declare function strictEqual<T>(item1: T, item2: T): boolean;
export declare function compareArrays<T>(array1: T[], array2: T[], comparator?: Comparator<T>): boolean;
/**
 * Compares DOM nodes for equality.
 * @param node1 The first node to compare.
 * @param node2 The second node to compare.
 * @param deep If true, the child nodes are compared recursively too.
 */
export declare function compareNodes(node1: Node, node2: Node, deep?: boolean): boolean;
/**
 * Gets a list of `node`'s ancestor nodes up until and including `rootNode`.
 * @param node Node whose ancestors to get.
 * @param rootNode The root node.
 */
export declare function getAncestors(node: Node, rootNode?: Node | null): Node[];
export declare function never(message?: string): never;
/**
 * Delegates the call to `diff.diffWordsWithSpace` and fixes the result, so that trailing `\0` characters
 * in the "added" and "removed" diff result items are moved to the front, if possible, which is necessary
 * to improve the quality of the DOM diffs.
 * Additionally, the "count" properties are set to undefined and empty diff items are removed.
 */
export declare function diffText(text1: string, text2: string, options?: IOptions): IDiffResult[];
